@@ -30,7 +30,7 @@ regExpGetGlobalNative(JSSyntaxRegExp regexp) {
 /// it finds a match.
 int regExpCaptureCount(JSSyntaxRegExp regexp) {
   var nativeAnchoredRegExp = regexp._nativeAnchoredVersion;
-  var match = JS('JSExtendableArray', '#.exec("")', nativeAnchoredRegExp);
+  JSArray match = JS('JSExtendableArray', '#.exec("")', nativeAnchoredRegExp);
   // The native-anchored regexp always have one capture more than the original,
   // and always matches the empty string.
   return match.length - 2;
@@ -46,10 +46,10 @@ class JSSyntaxRegExp implements RegExp {
       'RegExp/$pattern/' + JS('String', '#.flags', _nativeRegExp);
 
   JSSyntaxRegExp(String source,
-      {bool multiLine: false,
-      bool caseSensitive: true,
-      bool unicode: false,
-      bool dotAll: false})
+      {bool multiLine = false,
+      bool caseSensitive = true,
+      bool unicode = false,
+      bool dotAll = false})
       : this.pattern = source,
         this._nativeRegExp = makeNative(
             source, multiLine, caseSensitive, unicode, dotAll, false);
@@ -106,14 +106,14 @@ class JSSyntaxRegExp implements RegExp {
     // The returned value is the JavaScript exception. Turn it into a
     // Dart exception.
     String errorMessage = JS('String', r'String(#)', regexp);
-    throw new FormatException('Illegal RegExp pattern ($errorMessage)', source);
+    throw FormatException('Illegal RegExp pattern ($errorMessage)', source);
   }
 
   RegExpMatch? firstMatch(String string) {
     JSArray? m = JS('JSExtendableArray|Null', r'#.exec(#)', _nativeRegExp,
         checkString(string));
     if (m == null) return null;
-    return new _MatchImplementation(this, m);
+    return _MatchImplementation(this, m);
   }
 
   bool hasMatch(String string) {
@@ -130,9 +130,9 @@ class JSSyntaxRegExp implements RegExp {
     checkString(string);
     checkInt(start);
     if (start < 0 || start > string.length) {
-      throw new RangeError.range(start, 0, string.length);
+      throw RangeError.range(start, 0, string.length);
     }
-    return new _AllMatchesIterable(this, string, start);
+    return _AllMatchesIterable(this, string, start);
   }
 
   RegExpMatch? _execGlobal(String string, int start) {
@@ -140,7 +140,7 @@ class JSSyntaxRegExp implements RegExp {
     JS('void', '#.lastIndex = #', regexp, start);
     JSArray? match = JS('JSExtendableArray|Null', '#.exec(#)', regexp, string);
     if (match == null) return null;
-    return new _MatchImplementation(this, match);
+    return _MatchImplementation(this, match);
   }
 
   RegExpMatch? _execAnchored(String string, int start) {
@@ -151,12 +151,12 @@ class JSSyntaxRegExp implements RegExp {
     // If the last capture group participated, the original regexp did not
     // match at the start position.
     if (match.removeLast() != null) return null;
-    return new _MatchImplementation(this, match);
+    return _MatchImplementation(this, match);
   }
 
   RegExpMatch? matchAsPrefix(String string, [int start = 0]) {
     if (start < 0 || start > string.length) {
-      throw new RangeError.range(start, 0, string.length);
+      throw RangeError.range(start, 0, string.length);
     }
     return _execAnchored(string, start);
   }
@@ -168,7 +168,7 @@ class JSSyntaxRegExp implements RegExp {
 }
 
 class _MatchImplementation implements RegExpMatch {
-  final Pattern pattern;
+  final RegExp pattern;
   // Contains a JS RegExp match object.
   // It is an Array of String values with extra 'index' and 'input' properties.
   // If there were named capture groups, there will also be an extra 'groups'
@@ -222,7 +222,7 @@ class _MatchImplementation implements RegExpMatch {
   Iterable<String> get groupNames {
     var groups = JS('=Object|Null', '#.groups', _match);
     if (groups != null) {
-      var keys = new JSArray<String>.markGrowable(
+      var keys = JSArray<String>.markGrowable(
           JS('returns:JSExtendableArray;new:true', 'Object.keys(#)', groups));
       return SubListIterable(keys, 0, null);
     }
@@ -230,7 +230,7 @@ class _MatchImplementation implements RegExpMatch {
   }
 }
 
-class _AllMatchesIterable extends IterableBase<RegExpMatch> {
+class _AllMatchesIterable extends Iterable<RegExpMatch> {
   final JSSyntaxRegExp _re;
   final String _string;
   final int _start;
@@ -238,7 +238,7 @@ class _AllMatchesIterable extends IterableBase<RegExpMatch> {
   _AllMatchesIterable(this._re, this._string, this._start);
 
   Iterator<RegExpMatch> get iterator =>
-      new _AllMatchesIterator(_re, _string, _start);
+      _AllMatchesIterator(_re, _string, _start);
 }
 
 class _AllMatchesIterator implements Iterator<RegExpMatch> {
